@@ -2,7 +2,11 @@
 #include "ui_mainwindow.h"
 #include "loadprev.h"
 QString game;
+#ifdef Q_WS_MAEMO_5
 QString cfg_path="/home/user/.config/Team16/psx4m/";
+#else
+QString cfg_path= QString("%1/.config/Team16/psx4m/").arg(QDir::homePath());
+#endif
 QString bios_path="/home/user/MyDocs/";
 QString rom_path="/home/user/MyDocs";
 MainWindow::MainWindow(QWidget *parent) :
@@ -11,11 +15,11 @@ MainWindow::MainWindow(QWidget *parent) :
 {
     ui->setupUi(this);
 
-settings=new QSettings();
-bios_path=settings->value("bios_path","/home/user/MyDocs/").toString();
-if (bios_path.right(1)!="/")bios_path+="/";
- rom_path=settings->value("rom_path","/home/user/MyDocs/").toString();
- if (rom_path.right(1)!="/")rom_path+="/";
+    settings=new QSettings();
+    bios_path=settings->value("bios_path","/home/user/MyDocs/").toString();
+    if (bios_path.right(1)!="/") bios_path+="/";
+    rom_path=settings->value("rom_path","/home/user/MyDocs/").toString();
+    if (rom_path.right(1)!="/") rom_path+="/";
 
 #ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5StackedWindow);
@@ -26,85 +30,86 @@ if (bios_path.right(1)!="/")bios_path+="/";
     cfg->load_cfg();
 
 
-     QDir cfg_dir(cfg_path);
-     if (!cfg_dir.exists()){
-         if (!cfg_dir.mkdir(cfg_path))
-             qDebug("Can't create cfg dir, permission error?");
-         else
-             cfg->save_cfg();
-
-     }
+    QDir cfg_dir(cfg_path);
+    if (!cfg_dir.exists()){
+        if (!cfg_dir.mkdir(cfg_path))
+            qDebug("Can't create cfg dir, permission error?");
+        else
+            cfg->save_cfg();
+    }
 
     ui->listWidget->setStyleSheet("QListView::item{ height: 86px; }");
     ui->listWidget->setAutoFillBackground(true);
     ui->listWidget->setIconSize(QSize(144,80));
-    QDir dir(rom_path);
-         dir.setFilter(QDir::Files);
-         dir.setSorting(QDir::Name);
-         dir.setNameFilters(QStringList()<<"*.bin"<<"*.iso"<<"*.img");
 
-         QFileInfoList list = dir.entryInfoList();
-         int o=0;
-         for (int i = 0; i < list.size(); ++i) {
-             QFileInfo fileInfo = list.at(i);
-             if (fileInfo.fileName()=="scph1001.bin")continue;
-             QIcon icon(":/images/ICON0.PNG");
-             if (QFile::exists(QString("%1.png").arg(fileInfo.filePath())))
-                 icon = QIcon(QString("%1.png").arg(fileInfo.filePath()));
-             ui->listWidget->addItem(new QListWidgetItem(icon, fileInfo.fileName()));
-             roms.insert(o++,fileInfo.absoluteFilePath());
-         }
+    get_roms();
+
+    connect (ui->pushButton_2,SIGNAL(clicked()),this,SLOT(rom_config()));
+    connect (ui->pushButton,SIGNAL(clicked()),this,SLOT(rom_exec()));
+
+
+    this->menuBar()->addAction("Default config",this,SLOT(def_cfg()));
+    this->menuBar()->addAction("GUI config",this,SLOT(gui_cfg()));
+    this->menuBar()->addAction("Configure keys",this,SLOT(set_keys()));
+    this->menuBar()->addAction("Help",this,SLOT(open_help()));
+
+    connect(ui->listWidget,SIGNAL(currentRowChanged(int)),this,SLOT(currentRowChanged(int)));
+}
+
+void MainWindow::get_roms()
+{
+    qDebug() << "Reading roms from" << rom_path;
+    roms.clear();
+    ui->listWidget->clear();
+    QDir dir(rom_path);
+    dir.setFilter(QDir::Files);
+    dir.setSorting(QDir::Name);
+    dir.setNameFilters(QStringList()<<"*.bin"<<"*.iso"<<"*.img");
+
+    QFileInfoList list = dir.entryInfoList();
+    int o=0;
+    for (int i = 0; i < list.size(); ++i) {
+        QFileInfo fileInfo = list.at(i);
+        if (fileInfo.fileName()=="scph1001.bin") continue;
+        qDebug() << "  Rom:" << fileInfo.fileName();
+
+        QIcon icon(":/images/ICON0.PNG");
+        if (QFile::exists(QString("%1.png").arg(fileInfo.filePath())))
+            icon = QIcon(QString("%1.png").arg(fileInfo.filePath()));
+        ui->listWidget->addItem(new QListWidgetItem(icon, fileInfo.fileName()));
+        roms.insert(o++,fileInfo.absoluteFilePath());
+    }
     if (roms.count() > 0){
         ui->listWidget->setCurrentRow(0);
         currentRowChanged(0);
     }
-connect (ui->pushButton_2,SIGNAL(clicked()),this,SLOT(rom_config()));
-connect (ui->pushButton,SIGNAL(clicked()),this,SLOT(rom_exec()));
-
-
-this->menuBar()->addAction("Default config",this,SLOT(def_cfg()));
-this->menuBar()->addAction("GUI config",this,SLOT(gui_cfg()));
-this->menuBar()->addAction("Configure keys",this,SLOT(set_keys()));
-this->menuBar()->addAction("Help",this,SLOT(open_help()));
-
-connect(ui->listWidget,SIGNAL(currentRowChanged(int)),this,SLOT(currentRowChanged(int)));
 }
 
 void MainWindow::rom_exec(){
-if (ui->listWidget->currentRow()!=-1){
-    if (current_core=="pcsx"){
-QDir sc("/opt/maemo/usr/games/screenshots");
-QStringList st=sc.entryList(QStringList(ui->listWidget->currentItem()->text()+".*"),QDir::NoFilter,QDir::NoSort);
-if (st.count()>1){
-    bool ok;
-    QList <int> savest;
-    foreach(QString s,st)
-        savest.append(s.split(".").last().toInt(&ok, 10));
+    if (ui->listWidget->currentRow()!=-1){
+        if (current_core=="pcsx"){
+            QDir sc("/opt/maemo/usr/games/screenshots");
+            QStringList st=sc.entryList(QStringList(ui->listWidget->currentItem()->text()+".*"),QDir::NoFilter,QDir::NoSort);
+            if (st.count()>1){
+                bool ok;
+                QList <int> savest;
+                foreach(QString s,st)
+                savest.append(s.split(".").last().toInt(&ok, 10));
 
-    loadPrev *pr=new loadPrev(this);
-    pr->init(current_config,current_core,roms.value(ui->listWidget->currentRow()),savest);
-    pr->show();
-    return;
+                loadPrev *pr=new loadPrev(this);
+                pr->init(current_config,current_core,roms.value(ui->listWidget->currentRow()),savest);
+                pr->show();
+                return;
+            }
+        }
 
-}
-}
-
-QProcess *myProcess = new QProcess();
-QStringList args=current_config;
-//args<<roms.value(ui->listWidget->currentRow())<<"-save_name"<<(ui->listWidget->currentItem()->text());
-args<<roms.value(ui->listWidget->currentRow());
-qDebug (QString("%1 %2").arg("/opt/maemo/usr/games/"+current_core)
-        .arg(args.join(" ")).toAscii());
-myProcess->startDetached("/opt/maemo/usr/games/"+current_core, args,"/home/user/");
-
-
-
-
-
-
-
-
-}
+        QProcess *myProcess = new QProcess();
+        QStringList args=current_config;
+        //args<<roms.value(ui->listWidget->currentRow())<<"-save_name"<<(ui->listWidget->currentItem()->text());
+        args<<roms.value(ui->listWidget->currentRow());
+        qDebug (QString("%1 %2").arg("/opt/maemo/usr/games/"+current_core).arg(args.join(" ")).toAscii());
+        myProcess->startDetached("/opt/maemo/usr/games/"+current_core, args,"/home/user/");
+    }
 }
 
 void MainWindow::currentRowChanged ( int  ){
@@ -163,14 +168,15 @@ void MainWindow::set_keys(){
 
 void MainWindow::def_cfg() // Настройки которые будут применятся к играм по умолчанию настраиваются этим
 {
-game="";
-cfg->setWindowTitle("Config: default");
-cfg->show();
+    game="";
+    cfg->setWindowTitle("Config: default");
+    cfg->show();
 }
 
 void MainWindow::gui_cfg() // Настройки поведения GUI - rom dir,bios dir,exit after start
 {
     QDialog *dlg=new QDialog(this);
+    dlg->setMinimumWidth(200);
     dlg->setWindowTitle(tr("Gui config"));
     QGridLayout *lay=new QGridLayout(dlg);
 
@@ -193,18 +199,21 @@ void MainWindow::gui_cfg() // Настройки поведения GUI - rom di
 
 void MainWindow::set_rom_dir(){
     QString dir=QFileDialog::getExistingDirectory(this,tr("ROM Directory"),"/home/user/MyDocs/");
-    QString rom_path=dir;
-    settings->setValue("rom_path",rom_path);
-    lbl1->setText(rom_path);
-
-
+    if (!dir.isEmpty()){
+        rom_path=dir;
+        settings->setValue("rom_path",rom_path);
+        lbl1->setText(rom_path);
+        get_roms();
+    }
 }
 void MainWindow::set_bios_dir(){
     QString dir=QFileDialog::getExistingDirectory(this,tr("BIOS Directory"),"/home/user/MyDocs/");
-    QString bios_path=dir;
-    if (bios_path.right(1)!="/")bios_path+="/";
-    settings->setValue("bios_path",bios_path);
-    lbl2->setText(bios_path);
+    if (!dir.isEmpty()){
+        bios_path=dir;
+        if (bios_path.right(1)!="/")bios_path+="/";
+        settings->setValue("bios_path",bios_path);
+        lbl2->setText(bios_path);
+    }
 }
 
 void MainWindow::open_help() // Открытие страницы FAQ
@@ -213,17 +222,15 @@ void MainWindow::open_help() // Открытие страницы FAQ
 }
 
 
-
 MainWindow::~MainWindow()
 {
     delete ui;
 }
 
-
-void MainWindow::rom_config(){
+void MainWindow::rom_config()
+{
     if (ui->listWidget->currentRow()!=-1){
         cfg->setWindowTitle(tr("Config: %1").arg(game));
         cfg->show();
-}
-
+    }
 }
